@@ -161,12 +161,6 @@ def test_type_hint_reverse_invalid():
     assert deserialized == serialized
 
 
-def test_safe_kwargs():
-    mixed_args = lambda a, b=1, *c, d, e=1, **f: None
-    args = {x: x for x in mixed_args.__code__.co_varnames}
-    assert utils.safe_kwargs(mixed_args, args) == {'d': 'd', 'e': 'e'}
-
-
 @pytest.mark.parametrize(
     'value, expected',
     [
@@ -262,11 +256,11 @@ def test_parser_from_backend_class():
     assert known.j == 2
 
 
-def test_parse_unknown_args():
+def test_parse_cli_settings():
     args_list = [
         '--first-long-name.very-empty',
         '--second-long-name.single-value',
-        'true',
+        'none',
         '--third-long-name.multiple-values',
         '1',
         '2',
@@ -277,12 +271,29 @@ def test_parse_unknown_args():
         '--fourth-long-name.final',
         'abc',
         'def',
+        '--fifth',
+        'what?',
+        '--sixth',
+        '1_234',
+        '--seventh-trailing',
+    ]
+    parsed, unknown = utils.parse_cli_settings(args_list)
+    assert len(parsed) == 5
+    assert parsed['second_long_name.single_value'] is None
+    assert parsed['third_long_name.multiple_values'] == 1
+    assert parsed['fourth_long_name.final'] == 'abc'
+    assert parsed['fifth'] == 'what?'
+    assert parsed['sixth'] == 1234
+    assert unknown == [
+        '--first-long-name.very-empty',
+        '2',
+        '3',
+        '-a',
+        '4',
+        '5',
+        'def',
+        '--seventh-trailing',
     ]
-    parsed_args = utils.parse_unknown_args(args_list)
-    assert len(parsed_args) == 3
-    assert parsed_args['second_long_name.single_value'] is True
-    assert parsed_args['third_long_name.multiple_values'] == [1, 2, 3]
-    assert parsed_args['fourth_long_name.final'] == ['abc', 'def']
 
 
 def test_stream_files(tmp_path):
